GlobalFunctions class

Constructors

GlobalFunctions()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
screenSize(BuildContext context) Size
setHeight(BuildContext context, double height) double
setWidth(BuildContext context, double width) double
showInSnackBar(GlobalKey<ScaffoldState> _scaffoldKey, String message) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited