UserModel class

Constructors

UserModel({int id = 0, String userPayloadId = "", String firstName = "", String lastName = ""})
UserModel.fromJson(Map<String, dynamic> json)
factory

Properties

firstName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
lastName ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userPayloadId ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

userModel → UserModel
final